ReceivedRequestWriteHandle

Struct ReceivedRequestWriteHandle 

pub struct ReceivedRequestWriteHandle<F: Format> { /* private fields */ }
Write-only handle for a received buy_tomatoes request.

Implementations

Source

impl<F: Format> ReceivedRequestWriteHandle<F>

pub fn inner(&self) -> &ReceivedRequestWriteHandle<F::Body>

Get the raw request.

Note that the request body has been consumed when it was parsed. As a result, the raw request always has an empty body.

pub fn inner_mut(&self) -> &ReceivedRequestWriteHandle<F::Body>

Get an exclusive reference to the raw request.

Note that the request body has been consumed when it was parsed. As a result, the raw request always has an empty body.

pub fn into_inner(self) -> ReceivedRequestWriteHandle<F::Body>

Consume this object to get the raw request.

Note that the request body has been consumed when it was parsed. As a result, the raw request always has an empty body.

pub fn request_id(&self) -> u32

Get the request ID.

pub fn service_id(&self) -> i32

Get the service ID of the request.

pub async fn send_price_update(&self, update: &Price) -> Result<(), Error>
where F: EncodeBody<Price>,

Send a price update to the remote peer.

pub async fn send_response( &self, response: &BuyTomatoesResponse, ) -> Result<(), Error>

Send the final response.

pub async fn send_error_response(&self, error: &str) -> Result<(), Error>

Send the final response.