ReceivedRequestHandle

Enum ReceivedRequestHandle 

pub enum ReceivedRequestHandle<F: Format> {
    GreetCashier(ReceivedRequestHandle<F>, String),
    BuyTomatoes(ReceivedRequestHandle<F>, BuyTomatoesRequest),
}
Enum for all possible incoming requests of the Supermarket interface.

Variants



GreetCashier(ReceivedRequestHandle<F>, String)

Greet the cashier.

The cashier will reply with their own greeting.



BuyTomatoes(ReceivedRequestHandle<F>, BuyTomatoesRequest)

Purchase tomatoes.

The response of the cashier depends on the update messages exchanged. If you run away after they have sent the price, or if you pay with a nun-fungable token, they will respond with BuyTomatoesResponse::ICalledSecurity.

If you pay with the correct amount, they will respond with BuyTomatoesResponse::ThankYouComeAgain.