Interface

Struct Interface 

pub struct Interface { /* private fields */ }
Introspection for the Supermarket RPC interface.

Implementations

Source

impl Interface

pub const fn name() -> &'static str

Get the name of the interface.

pub const fn doc() -> &'static str

Get the documentation of the interface.

This string may contain rustdoc compatible markup.

pub fn definition<F>() -> InterfaceDefinition<F::TypeInfo>

Get the full interface definition.

The type information for message bodies depends on serialization format used.

pub fn services<F>() -> Vec<ServiceDefinition<F::TypeInfo>>

Get the list of services in the interface.

The type information for message bodies depends on serialization format used.

pub fn streams<F>() -> Vec<StreamDefinition<F::TypeInfo>>

Get the list of streams in the interface.

The type information for message bodies depends on serialization format used.