pub struct Receipt {
pub amount_of_tomatoes: usize,
pub total_price_cents: usize,
pub phone_number: Option<String>,
}Expand description
A receipt for your purchase.
Fields
amount_of_tomatoes: usizeThe number of tomatoes you bought.
total_price_cents: usizeThe total price you paid for the tomatoes.
phone_number: Option<String>If the cashier really liked you, they may write their phone number on the receipt with pen.