pub struct Interface { /* private fields */ }Expand description
Introspection for the Supermarket RPC interface.
Implementations
Sourceimpl Interface
impl Interface
Sourcepub const fn doc() -> &'static str
pub const fn doc() -> &'static str
Get the documentation of the interface.
This string may contain rustdoc compatible markup.
Sourcepub fn definition<F>() -> InterfaceDefinition<F::TypeInfo>
pub fn definition<F>() -> InterfaceDefinition<F::TypeInfo>
Get the full interface definition.
The type information for message bodies depends on serialization format used.
Sourcepub fn services<F>() -> Vec<ServiceDefinition<F::TypeInfo>>
pub fn services<F>() -> Vec<ServiceDefinition<F::TypeInfo>>
Get the list of services in the interface.
The type information for message bodies depends on serialization format used.
Sourcepub fn streams<F>() -> Vec<StreamDefinition<F::TypeInfo>>
pub fn streams<F>() -> Vec<StreamDefinition<F::TypeInfo>>
Get the list of streams in the interface.
The type information for message bodies depends on serialization format used.