pub trait Format:
Format
+ EncodeBody<String>
+ DecodeBody<String>
+ EncodeBody<String>
+ DecodeBody<String>
+ EncodeBody<BuyTomatoesRequest>
+ DecodeBody<BuyTomatoesRequest>
+ EncodeBody<BuyTomatoesResponse>
+ DecodeBody<BuyTomatoesResponse>
+ EncodeBody<Payment>
+ DecodeBody<Payment>
+ EncodeBody<()>
+ DecodeBody<()>
+ EncodeBody<Price>
+ DecodeBody<Price>
+ EncodeBody<String>
+ DecodeBody<String> { }Expand description
Trait for formats that are compatible with this interface.
A format is compatible when it can encode and decode all messages that appear in the interface. It is automatically implemented for all compatible formats.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".